==> pure-www-18.5.2.zip: src/www/Dialvox/application/language/english/homeagente_lang.php <==
<?php

$lang["desc_campanaSinListaNegra"] = "The campaign does not have a black list";
$lang["desc_noSe"] = "Unknown action";
$lang["desc_sinSesion"] = "No current session initiated"; 
$lang["desc_noSupervisor"] = "Not a supervisor"; 
$lang["desc_usuarioInexistente"] = "User does not exist";
$lang["desc_guardarLog"] = "Log could not be saved"; 
$lang["desc_callbackRegistrado"] = "Callback registered successfully"; 
$lang["desc_callbackEliminado"] = "Callback deleted successfully";
$lang["desc_sinCallbacks"] = "No callbacks to assign"; 
$lang["men_callbackAsignado"] = "Callback assigned correctly";
$lang["men_callbacksObtenidos"] = "Callbacks retreived successfully"; 


// Textos en la vista de agente =======================================================

$lang["llamadasPendientes"] = "PENDING CALLS";
$lang["solicitaAyuda"] = "Request help from a supervisor";
$lang["salir"] = "Exit";
$lang["controles"] = "Controls";
$lang["historialLlamadas"] = "Call log";
$lang["llamadasSesion"] = "Calls for this session";
$lang["sinGrabacion"] = "No recording";
$lang["sinLlamadas"] = "There are no call in this session";
$lang["canales"] = "Channels";
$lang["enviarReporte"] = "Send report";
$lang["notasReporte"] = "Enter here the notes about what happened";
$lang["llamando"] = "Calling";
$lang["calificar"] = "Rate";
$lang["fechaVolverLlamar"] = "Date to call again";
$lang["horaVolverLlamar"] = "Time to call again";
$lang["comentariosCallback"] = "Comments for callback";
$lang["tipoCallback"] = "Type of callback";
$lang["callbackCualquiera"] = "Any agent";
$lang["callbackYo"] = "For me only";
$lang["calificacion"] = "Rating";
$lang["comentarios"] = "Comments";
$lang["pausaCalificar"] = "Pause when raiting";
$lang["codigosPausa"] = "Pause codes";
$lang["codigoPausa"] = "Pause code";
$lang["limitePausa"] = "You have exceded the configuration limits for this type of pause!";
$lang["ingresaSupervisor"] = "This requires for a supervisor to login";
$lang["usuario"] = "User";
$lang["password"] = "Password";
$lang["acceder"] = "Access";
$lang["agregarLlamada"] = "Add a channel to the call";
$lang["telefono"] = "Telephone";
$lang["cerrar"] = "Close";
$lang["marcar"] = "Dial";
$lang["aviso"] = "Aviso";
$lang["espera"] = "Put on hold";
$lang["colgar"] = "Hang up";
$lang["volverMarcar"] = "Dial again";
$lang["transferir"] = "Transfer Call";
$lang["multiplesDtmf"] = "Sending multiple DTMFs";
$lang["avisoDtmf"] = "Solo numeros o caracteres especiales como \'*\' o \'#\'";
$lang["confirmar"] = "Confirm";
$lang["cancelar"] = "Cancel";

// Textos en la vista de agente =======================================================

?>

==> pure-www-18.5.20.zip: src/www/Dialvox/application/language/english/homeagente_lang.php <==
<?php

$lang["desc_campanaSinListaNegra"] = "The campaign does not have a black list";
$lang["desc_noSe"] = "Unknown action";
$lang["desc_sinSesion"] = "No current session initiated";
$lang["desc_noSupervisor"] = "Not a supervisor";
$lang["desc_usuarioInexistente"] = "User does not exist";
$lang["desc_guardarLog"] = "Log could not be saved";
$lang["desc_callbackRegistrado"] = "Callback registered successfully";
$lang["desc_callbackEliminado"] = "Callback deleted successfully";
$lang["desc_sinCallbacks"] = "No callbacks to assign";
$lang["men_callbackAsignado"] = "Callback assigned correctly";
$lang["men_callbacksObtenidos"] = "Callbacks retreived successfully";


// Textos en la vista de agente =======================================================

$lang["llamadasPendientes"] = "PENDING CALLS";
$lang["solicitaAyuda"] = "Request help from a supervisor";
$lang["salir"] = "Exit";
$lang["controles"] = "Controls";
$lang["historialLlamadas"] = "Call log";
$lang["llamadasSesion"] = "TODAY CALLS";
$lan["historialGrabacion"] = "Recording";
$lang["sinGrabacion"] = "No recording";
$lang["sinLlamadas"] = "There are no call in this session";
$lang["canales"] = "Audios";
$lang["enviarReporte"] = "Send report";
$lang["notasReporte"] = "Enter here the notes about what happened";
$lang["llamando"] = "Calling";
$lang["calificar"] = "Rate";
$lang["fechaVolverLlamar"] = "Date to call again";
$lang["horaVolverLlamar"] = "Time to call again";
$lang["comentariosCallback"] = "Comments for callback";
$lang["tipoCallback"] = "Type of callback";
$lang["callbackCualquiera"] = "Any agent";
$lang["callbackYo"] = "For me only";
$lang["calificacion"] = "Rating";
$lang["comentarios"] = "Comments";
$lang["pausaCalificar"] = "Pause when raiting";
$lang["codigosPausa"] = "Pause codes";
$lang["codigoPausa"] = "Pause code";
$lang["limitePausa"] = "You have exceded the configuration limits for this type of pause!";
$lang["ingresaSupervisor"] = "This requires for a supervisor to login";
$lang["usuario"] = "User";
$lang["password"] = "Password";
$lang["acceder"] = "Access";
$lang["agregarLlamada"] = "Add a channel to the call";
$lang["telefono"] = "Telephone";
$lang["cerrar"] = "Close";
$lang["marcar"] = "Dial";
$lang["aviso"] = "Aviso";
$lang["espera"] = "Put on hold";
$lang["colgar"] = "Hang up";
$lang["volverMarcar"] = "Dial again";
$lang["transferir"] = "Transfer Call";
$lang["multiplesDtmf"] = "Sending multiple DTMFs";
$lang["avisoDtmf"] = "Solo numeros o caracteres especiales como \'*\' o \'#\'";
$lang["confirmar"] = "Confirm";
$lang["cancelar"] = "Cancel";

$lang["transferenciaAgenteTitulo"] = "Transfer to agent";
$lang["gruposAgente"] = "Agente Groups";

// Textos en la vista de agente =======================================================
